==> qtjambi-network-debuginfo-windows-x64-6.5.6.jar: sources/QtJambiNetwork/QAbstractSocket_shell.h <==
#ifndef QABSTRACTSOCKET_SHELL_H
#define QABSTRACTSOCKET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qabstractsocket.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtJambi/RegistryAPI>


class QAbstractSocket_shell : public QAbstractSocket, public QtJambiShellInterface
{
public:
    QAbstractSocket_shell(QAbstractSocket::SocketType socketType0, QObject* parent1);
    ~QAbstractSocket_shell() override;

    bool atEnd() const override;
    bool bind(const QHostAddress& address0, quint16 port1, QAbstractSocket::BindMode mode2) override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void connectToHost(const QString& hostName0, quint16 port1, QIODeviceBase::OpenMode mode2, QAbstractSocket::NetworkLayerProtocol protocol3) override;
    void customEvent(QEvent* event0) override;
    void disconnectFromHost() override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODeviceBase::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    void resume() override;
    bool seek(qint64 pos0) override;
    void setReadBufferSize(qint64 size0) override;
    bool setSocketDescriptor(qintptr socketDescriptor0, QAbstractSocket::SocketState state1, QIODeviceBase::OpenMode openMode2) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize0) override;
    qintptr socketDescriptor() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForConnected(int msecs0) override;
    bool waitForDisconnected(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractSocket_access : public QAbstractSocket
{
    void __qt_setLocalAddress_cref_QHostAddress(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    void __qt_setLocalPort_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint port0);
    void __qt_setPeerAddress_cref_QHostAddress(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    void __qt_setPeerName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    void __qt_setPeerPort_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint port0);
    void __qt_setSocketError_QAbstractSocket_SocketError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint socketError0);
    void __qt_setSocketState_QAbstractSocket_SocketState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jboolean __qt_bind_cref_QHostAddress_quint16_QAbstractSocket_BindMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0, jint port1, jint mode2);
    jlong __qt_bytesAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectToHost_cref_QString_quint16_QIODeviceBase_OpenMode_QAbstractSocket_NetworkLayerProtocol(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring hostName0, jint port1, jint mode2, jint protocol3);
    void __qt_disconnectFromHost(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLineData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setReadBufferSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    jboolean __qt_setSocketDescriptor_qintptr_QAbstractSocket_SocketState_QIODeviceBase_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socketDescriptor0, jint state1, jint openMode2);
    jlong __qt_skipData_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong maxSize0);
    jlong __qt_socketDescriptor_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_waitForBytesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForConnected_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForDisconnected_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForReadyRead_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QABSTRACTSOCKET_SHELL_H

==> qtjambi-network-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiNetwork/QAbstractSocket_shell.h <==
#ifndef QABSTRACTSOCKET_SHELL_H
#define QABSTRACTSOCKET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetwork/qabstractsocket.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtJambi/RegistryAPI>


class QAbstractSocket_shell : public QAbstractSocket, public QtJambiShellInterface
{
public:
    QAbstractSocket_shell(QAbstractSocket::SocketType socketType0, QObject* parent1);
    ~QAbstractSocket_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QAbstractSocket_mshell;
    friend class QAbstractSocket_oshell;
};


class QAbstractSocket_mshell : public QAbstractSocket_shell
{
public:
    using QAbstractSocket_shell::QAbstractSocket_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QAbstractSocket_oshell : public QAbstractSocket_mshell
{
public:
    using QAbstractSocket_mshell::QAbstractSocket_mshell;
    bool atEnd() const override;
    bool bind(const QHostAddress& address0, quint16 port1, QAbstractSocket::BindMode mode2) override;
    qint64 bytesAvailable() const override;
    qint64 bytesToWrite() const override;
    bool canReadLine() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void connectToHost(const QString& hostName0, quint16 port1, QIODeviceBase::OpenMode mode2, QAbstractSocket::NetworkLayerProtocol protocol3) override;
    void customEvent(QEvent* event0) override;
    void disconnectFromHost() override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isSequential() const override;
    bool open(QIODeviceBase::OpenMode mode0) override;
    qint64 pos() const override;
    qint64 readData(char* data0, qint64 maxlen1) override;
    qint64 readLineData(char* data0, qint64 maxlen1) override;
    bool reset() override;
    void resume() override;
    bool seek(qint64 pos0) override;
    void setReadBufferSize(qint64 size0) override;
    bool setSocketDescriptor(qintptr socketDescriptor0, QAbstractSocket::SocketState state1, QIODeviceBase::OpenMode openMode2) override;
    qint64 size() const override;
    qint64 skipData(qint64 maxSize0) override;
    qintptr socketDescriptor() const override;
    void timerEvent(QTimerEvent* event0) override;
    bool waitForBytesWritten(int msecs0) override;
    bool waitForConnected(int msecs0) override;
    bool waitForDisconnected(int msecs0) override;
    bool waitForReadyRead(int msecs0) override;
    qint64 writeData(const char* data0, qint64 len1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractSocket_access : public QAbstractSocket
{
    void __qt_setLocalAddress_cref_QHostAddress(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    void __qt_setLocalPort_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint port0);
    void __qt_setPeerAddress_cref_QHostAddress(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0);
    void __qt_setPeerName_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
    void __qt_setPeerPort_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint port0);
    void __qt_setSocketError_QAbstractSocket_SocketError(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint socketError0);
    void __qt_setSocketState_QAbstractSocket_SocketState(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint state0);
    jboolean __qt_bind_cref_QHostAddress_quint16_QAbstractSocket_BindMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID address0, jint port1, jint mode2);
    jlong __qt_bytesAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_bytesToWrite_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_close(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_connectToHost_cref_QString_quint16_QIODeviceBase_OpenMode_QAbstractSocket_NetworkLayerProtocol(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring hostName0, jint port1, jint mode2, jint protocol3);
    void __qt_disconnectFromHost(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_isSequential_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_readData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    jint __qt_readLineData_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
    void __qt_resume(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setReadBufferSize_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong size0);
    jboolean __qt_setSocketDescriptor_qintptr_QAbstractSocket_SocketState_QIODeviceBase_OpenMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong socketDescriptor0, jint state1, jint openMode2);
    jlong __qt_skipData_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jlong maxSize0);
    jlong __qt_socketDescriptor_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_waitForBytesWritten_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForConnected_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForDisconnected_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jboolean __qt_waitForReadyRead_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msecs0);
    jint __qt_writeData_const_char_ptr_qint64(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject data0);
};

#endif // QABSTRACTSOCKET_SHELL_H
